@@ -28,26 +28,29 @@
 
 #include "android_global.h"
 
+#include "androidbuildapkstep.h"
+#include "androidextralibrarylistmodel.h"
+#include "androidqtsupport.h"
+
 #include <projectexplorer/buildstep.h>
 
-#include <QWidget>
+#include <QListView>
+#include <QToolButton>
 
 QT_BEGIN_NAMESPACE
 namespace Ui { class AndroidBuildApkWidget; }
 QT_END_NAMESPACE
 
-namespace QmakeProjectManager { class QmakeBuildConfiguration; }
-
 namespace Android {
-class AndroidBuildApkStep;
+namespace Internal {
 
-class ANDROID_EXPORT AndroidBuildApkWidget : public ProjectExplorer::BuildStepConfigWidget
+class AndroidBuildApkInnerWidget : public ProjectExplorer::BuildStepConfigWidget
 {
     Q_OBJECT
 
 public:
-    AndroidBuildApkWidget(AndroidBuildApkStep *step);
-    ~AndroidBuildApkWidget() override;
+    AndroidBuildApkInnerWidget(AndroidBuildApkStep *step);
+    ~AndroidBuildApkInnerWidget() override;
 
 private:
     void setTargetSdk(const QString &sdk);
@@ -68,4 +71,32 @@ private:
     AndroidBuildApkStep *m_step;
 };
 
-}
+class AndroidBuildApkWidget : public ProjectExplorer::BuildStepConfigWidget
+{
+    Q_OBJECT
+
+public:
+    explicit AndroidBuildApkWidget(AndroidBuildApkStep *step);
+
+signals:
+    void requestAndroidTemplates();
+
+private:
+    void addAndroidExtraLib();
+    void removeAndroidExtraLib();
+    void checkEnableRemoveButton();
+
+    QString summaryText() const final;
+    QString displayName() const final;
+
+private:
+    QListView *m_androidExtraLibsListView = nullptr;
+    QToolButton *m_removeAndroidExtraLibButton = nullptr;
+
+    AndroidBuildApkStep *m_step = nullptr;
+    Android::AndroidExtraLibraryListModel *m_extraLibraryListModel = nullptr;
+    bool m_ignoreChange = false;
+};
+
+} // namespace Internal
+} // namespace Android
