@@ -24,8 +24,9 @@
 ****************************************************************************/
 
 #include "bineditorplugin.h"
-#include "bineditor.h"
+#include "bineditorwidget.h"
 #include "bineditorconstants.h"
+#include "bineditorservice.h"
 
 #include <coreplugin/icore.h>
 
@@ -59,30 +60,6 @@ using namespace Utils;
 using namespace Core;
 
 namespace BinEditor {
-
-///////////////////////////////// BinEditorWidgetFactory //////////////////////////////////
-
-/*!
-   \class BinEditor::BinEditorWidgetFactory
-   \brief The BinEditorWidgetFactory class offers a service registered with
-   PluginManager to create bin editor widgets for plugins
-   without direct linkage.
-
-   \sa ExtensionSystem::PluginManager::getObjectByClassName, ExtensionSystem::invoke
-*/
-
-class BinEditorWidgetFactory : public QObject
-{
-    Q_OBJECT
-public:
-    BinEditorWidgetFactory() {}
-
-    Q_INVOKABLE QWidget *createWidget(QWidget *parent)
-    {
-        return new BinEditorWidget(parent);
-    }
-};
-
 namespace Internal {
 
 class BinEditorFind : public IFindSupport
@@ -93,31 +70,29 @@ public:
     BinEditorFind(BinEditorWidget *widget)
     {
         m_widget = widget;
-        m_incrementalStartPos = m_contPos = -1;
-        m_incrementalWrappedState = false;
     }
 
-    bool supportsReplace() const { return false; }
-    QString currentFindString() const { return QString(); }
-    QString completedFindString() const { return QString(); }
+    bool supportsReplace() const override { return false; }
+    QString currentFindString() const override { return QString(); }
+    QString completedFindString() const override { return QString(); }
 
-    FindFlags supportedFindFlags() const
+    FindFlags supportedFindFlags() const override
     {
         return FindBackward | FindCaseSensitively;
     }
 
-    void resetIncrementalSearch()
+    void resetIncrementalSearch() override
     {
         m_incrementalStartPos = m_contPos = -1;
         m_incrementalWrappedState = false;
     }
 
-    virtual void highlightAll(const QString &txt, FindFlags findFlags)
+    void highlightAll(const QString &txt, FindFlags findFlags) override
     {
         m_widget->highlightSearchResults(txt.toLatin1(), textDocumentFlagsForFindFlags(findFlags));
     }
 
-    void clearHighlights()
+    void clearHighlights() override
     {
         m_widget->highlightSearchResults(QByteArray());
     }
@@ -143,7 +118,8 @@ public:
         return res;
     }
 
-    Result findIncremental(const QString &txt, FindFlags findFlags) {
+    Result findIncremental(const QString &txt, FindFlags findFlags) override
+    {
         QByteArray pattern = txt.toLatin1();
         if (pattern != m_lastPattern)
             resetIncrementalSearch(); // Because we don't search for nibbles.
@@ -178,11 +154,12 @@ public:
         return result;
     }
 
-    Result findStep(const QString &txt, FindFlags findFlags) {
+    Result findStep(const QString &txt, FindFlags findFlags) override
+    {
         QByteArray pattern = txt.toLatin1();
         bool wasReset = (m_incrementalStartPos < 0);
         if (m_contPos == -1) {
-            m_contPos = m_widget->cursorPosition();
+            m_contPos = m_widget->cursorPosition() + 1;
             if (findFlags & FindBackward)
                 m_contPos = m_widget->selectionStart()-1;
         }
@@ -211,9 +188,9 @@ public:
 
 private:
     BinEditorWidget *m_widget;
-    int m_incrementalStartPos;
-    int m_contPos; // Only valid if last result was NotYetFound.
-    bool m_incrementalWrappedState;
+    qint64 m_incrementalStartPos = -1;
+    qint64 m_contPos = -1; // Only valid if last result was NotYetFound.
+    bool m_incrementalWrappedState = false;
     QByteArray m_lastPattern;
 };
 
@@ -228,11 +205,10 @@ public:
         setId(Core::Constants::K_DEFAULT_BINARY_EDITOR_ID);
         setMimeType(QLatin1String(BinEditor::Constants::C_BINEDITOR_MIMETYPE));
         m_widget = parent;
-        connect(m_widget, SIGNAL(dataRequested(quint64)),
-            this, SLOT(provideData(quint64)));
-        connect(m_widget, SIGNAL(newRangeRequested(quint64)),
-            this, SLOT(provideNewRange(quint64)));
-        connect(m_widget, &BinEditorWidget::dataChanged, this, &IDocument::contentsChanged);
+        EditorService *es = m_widget->editorService();
+        es->setFetchDataHandler([this](quint64 address) { provideData(address); });
+        es->setNewRangeRequestHandler([this](quint64 offset) { provideNewRange(offset); });
+        es->setDataChangedHandler([this](quint64, const QByteArray &) { contentsChanged(); });
     }
 
     QByteArray contents() const override
@@ -252,8 +228,7 @@ public:
 
     ReloadBehavior reloadBehavior(ChangeTrigger state, ChangeType type) const override
     {
-        Q_UNUSED(state)
-        return type == TypeRemoved ? BehaviorSilent : BehaviorAsk;
+        return type == TypeRemoved ? BehaviorSilent : IDocument::reloadBehavior(state, type);
     }
 
     bool save(QString *errorString, const QString &fn, bool autoSave) override
@@ -289,8 +264,9 @@ public:
                     QMessageBox::critical(ICore::mainWindow(), tr("File Error"), msg);
                 return OpenResult::CannotHandle;
             }
-            if (size > INT_MAX) {
-                QString msg = tr("The file is too big for the Binary Editor (max. 2GB).");
+            if (size / 16 >= qint64(1) << 31) {
+                // The limit is 2^31 lines (due to QText* interfaces) * 16 bytes per line.
+                QString msg = tr("The file is too big for the Binary Editor (max. 32GB).");
                 if (errorString)
                     *errorString = msg;
                 else
@@ -312,8 +288,7 @@ public:
         return OpenResult::ReadError;
     }
 
-private slots:
-    void provideData(quint64 block)
+    void provideData(quint64 address)
     {
         const FileName fn = filePath();
         if (fn.isEmpty())
@@ -321,13 +296,13 @@ private slots:
         QFile file(fn.toString());
         if (file.open(QIODevice::ReadOnly)) {
             int blockSize = m_widget->dataBlockSize();
-            file.seek(block * blockSize);
+            file.seek(address);
             QByteArray data = file.read(blockSize);
             file.close();
             const int dataSize = data.size();
             if (dataSize != blockSize)
                 data += QByteArray(blockSize - dataSize, 0);
-            m_widget->addData(block, data);
+            m_widget->addData(address, data);
         } else {
             QMessageBox::critical(ICore::mainWindow(), tr("File Error"),
                                   tr("Cannot open %1: %2").arg(
@@ -337,11 +312,11 @@ private slots:
 
     void provideNewRange(quint64 offset)
     {
-        openImpl(0, filePath().toString(), offset);
+        if (filePath().exists())
+            openImpl(0, filePath().toString(), offset);
     }
 
 public:
-
     bool isModified() const override
     {
         return isTemporary()/*e.g. memory view*/ ? false
@@ -357,7 +332,8 @@ public:
 
     bool isSaveAsAllowed() const override { return true; }
 
-    bool reload(QString *errorString, ReloadFlag flag, ChangeType type) override {
+    bool reload(QString *errorString, ReloadFlag flag, ChangeType type) override
+    {
         if (flag == FlagIgnore)
             return true;
         if (type == TypePermissions) {
@@ -386,16 +362,12 @@ public:
     {
         setWidget(widget);
         m_file = new BinEditorDocument(widget);
-        m_context.add(Core::Constants::K_DEFAULT_BINARY_EDITOR_ID);
-        m_context.add(Constants::C_BINEDITOR);
         m_addressEdit = new QLineEdit;
-        QRegExpValidator * const addressValidator
-            = new QRegExpValidator(QRegExp(QLatin1String("[0-9a-fA-F]{1,16}")),
-                m_addressEdit);
+        auto addressValidator = new QRegExpValidator(QRegExp("[0-9a-fA-F]{1,16}"), m_addressEdit);
         m_addressEdit->setValidator(addressValidator);
 
-        QHBoxLayout *l = new QHBoxLayout;
-        QWidget *w = new QWidget;
+        auto l = new QHBoxLayout;
+        auto w = new QWidget;
         l->setMargin(0);
         l->setContentsMargins(0, 0, 5, 0);
         l->addStretch(1);
@@ -408,9 +380,12 @@ public:
 
         widget->setEditor(this);
 
-        connect(widget, SIGNAL(cursorPositionChanged(int)), SLOT(updateCursorPosition(int)));
-        connect(m_addressEdit, SIGNAL(editingFinished()), SLOT(jumpToAddress()));
-        connect(widget, SIGNAL(modificationChanged(bool)), m_file, SIGNAL(changed()));
+        connect(widget, &BinEditorWidget::cursorPositionChanged,
+                this, &BinEditor::updateCursorPosition);
+        connect(m_addressEdit, &QLineEdit::editingFinished,
+                this, &BinEditor::jumpToAddress);
+        connect(widget, &BinEditorWidget::modificationChanged,
+                m_file, &IDocument::changed);
         updateCursorPosition(widget->cursorPosition());
     }
 
@@ -419,12 +394,12 @@ public:
         delete m_widget;
     }
 
-    IDocument *document() override { return m_file; }
+    IDocument *document() const override { return m_file; }
 
     QWidget *toolBar() override { return m_toolBar; }
 
-private slots:
-    void updateCursorPosition(int position) {
+private:
+    void updateCursorPosition(qint64 position) {
         m_addressEdit->setText(QString::number(editorWidget()->baseAddress() + position, 16));
     }
 
@@ -433,8 +408,7 @@ private slots:
         updateCursorPosition(editorWidget()->cursorPosition());
     }
 
-private:
-    inline BinEditorWidget *editorWidget() const
+    BinEditorWidget *editorWidget() const
     {
         QTC_ASSERT(qobject_cast<BinEditorWidget *>(m_widget.data()), return 0);
         return static_cast<BinEditorWidget *>(m_widget.data());
@@ -446,76 +420,113 @@ private:
     QLineEdit *m_addressEdit;
 };
 
+///////////////////////////////// BinEditorPluginPrivate //////////////////////////////////
 
+class BinEditorPluginPrivate : public QObject
+{
+public:
+    BinEditorPluginPrivate();
+    ~BinEditorPluginPrivate();
+
+    QAction *m_undoAction = nullptr;
+    QAction *m_redoAction = nullptr;
+    QAction *m_copyAction = nullptr;
+    QAction *m_selectAllAction = nullptr;
+
+    FactoryServiceImpl m_factoryService;
+    BinEditorFactory m_editorFactory;
+};
+
+BinEditorPluginPrivate::BinEditorPluginPrivate()
+{
+    ExtensionSystem::PluginManager::addObject(&m_factoryService);
+    ExtensionSystem::PluginManager::addObject(&m_editorFactory);
+
+    m_undoAction = new QAction(BinEditorPlugin::tr("&Undo"), this);
+    m_redoAction = new QAction(BinEditorPlugin::tr("&Redo"), this);
+    m_copyAction = new QAction(this);
+    m_selectAllAction = new QAction(this);
+
+    Context context;
+    context.add(Core::Constants::K_DEFAULT_BINARY_EDITOR_ID);
+    context.add(Constants::C_BINEDITOR);
+
+    ActionManager::registerAction(m_undoAction, Core::Constants::UNDO, context);
+    ActionManager::registerAction(m_redoAction, Core::Constants::REDO, context);
+    ActionManager::registerAction(m_copyAction, Core::Constants::COPY, context);
+    ActionManager::registerAction(m_selectAllAction, Core::Constants::SELECTALL, context);
+}
+
+BinEditorPluginPrivate::~BinEditorPluginPrivate()
+{
+    ExtensionSystem::PluginManager::removeObject(&m_editorFactory);
+    ExtensionSystem::PluginManager::removeObject(&m_factoryService);
+}
+
+static BinEditorPluginPrivate *dd = nullptr;
 
 ///////////////////////////////// BinEditorFactory //////////////////////////////////
 
-BinEditorFactory::BinEditorFactory(BinEditorPlugin *owner) :
-    m_owner(owner)
+BinEditorFactory::BinEditorFactory()
 {
     setId(Core::Constants::K_DEFAULT_BINARY_EDITOR_ID);
-    setDisplayName(qApp->translate("OpenWith::Editors", Constants::C_BINEDITOR_DISPLAY_NAME));
+    setDisplayName(QCoreApplication::translate("OpenWith::Editors", Constants::C_BINEDITOR_DISPLAY_NAME));
     addMimeType(Constants::C_BINEDITOR_MIMETYPE);
 }
 
 IEditor *BinEditorFactory::createEditor()
 {
-    BinEditorWidget *widget = new BinEditorWidget();
-    BinEditor *editor = new BinEditor(widget);
+    auto widget = new BinEditorWidget();
+    auto editor = new BinEditor(widget);
+
+    connect(dd->m_undoAction, &QAction::triggered, widget, &BinEditorWidget::undo);
+    connect(dd->m_redoAction, &QAction::triggered, widget, &BinEditorWidget::redo);
+    connect(dd->m_copyAction, &QAction::triggered, widget, &BinEditorWidget::copy);
+    connect(dd->m_selectAllAction, &QAction::triggered, widget, &BinEditorWidget::selectAll);
+
+    auto updateActions = [widget] {
+        dd->m_selectAllAction->setEnabled(true);
+        dd->m_undoAction->setEnabled(widget->isUndoAvailable());
+        dd->m_redoAction->setEnabled(widget->isRedoAvailable());
+    };
+
+    connect(widget, &BinEditorWidget::undoAvailable, widget, updateActions);
+    connect(widget, &BinEditorWidget::redoAvailable, widget, updateActions);
+
+    auto aggregate = new Aggregation::Aggregate;
+    auto binEditorFind = new BinEditorFind(widget);
+    aggregate->add(binEditorFind);
+    aggregate->add(widget);
 
-    m_owner->initializeEditor(widget);
     return editor;
 }
 
+///////////////////////////////// BinEditor Services //////////////////////////////////
+
+EditorService *FactoryServiceImpl::createEditorService(const QString &title0, bool wantsEditor)
+{
+    BinEditorWidget *widget = nullptr;
+    if (wantsEditor) {
+        QString title = title0;
+        IEditor *editor = EditorManager::openEditorWithContents(
+                    Core::Constants::K_DEFAULT_BINARY_EDITOR_ID, &title);
+        if (!editor)
+            return 0;
+        widget = qobject_cast<BinEditorWidget *>(editor->widget());
+        widget->setEditor(editor);
+    } else {
+        widget = new BinEditorWidget;
+        widget->setWindowTitle(title0);
+    }
+    return widget->editorService();
+}
 
 ///////////////////////////////// BinEditorPlugin //////////////////////////////////
 
-BinEditorPlugin::BinEditorPlugin()
-{
-    m_undoAction = m_redoAction = m_copyAction = m_selectAllAction = 0;
-}
-
 BinEditorPlugin::~BinEditorPlugin()
 {
-}
-
-QAction *BinEditorPlugin::registerNewAction(Id id, const QString &title)
-{
-    QAction *result = new QAction(title, this);
-    ActionManager::registerAction(result, id, m_context);
-    return result;
-}
-
-QAction *BinEditorPlugin::registerNewAction(Id id,
-                                            QObject *receiver,
-                                            const char *slot,
-                                            const QString &title)
-{
-    QAction *rc = registerNewAction(id, title);
-    if (!rc)
-        return 0;
-
-    connect(rc, SIGNAL(triggered()), receiver, slot);
-    return rc;
-}
-
-void BinEditorPlugin::initializeEditor(BinEditorWidget *widget)
-{
-    m_context.add(Constants::C_BINEDITOR);
-    if (!m_undoAction) {
-        m_undoAction      = registerNewAction(Core::Constants::UNDO, this, SLOT(undoAction()), tr("&Undo"));
-        m_redoAction      = registerNewAction(Core::Constants::REDO, this, SLOT(redoAction()), tr("&Redo"));
-        m_copyAction      = registerNewAction(Core::Constants::COPY, this, SLOT(copyAction()));
-        m_selectAllAction = registerNewAction(Core::Constants::SELECTALL, this, SLOT(selectAllAction()));
-    }
-
-    QObject::connect(widget, SIGNAL(undoAvailable(bool)), this, SLOT(updateActions()));
-    QObject::connect(widget, SIGNAL(redoAvailable(bool)), this, SLOT(updateActions()));
-
-    Aggregation::Aggregate *aggregate = new Aggregation::Aggregate;
-    BinEditorFind *binEditorFind = new BinEditorFind(widget);
-    aggregate->add(binEditorFind);
-    aggregate->add(widget);
+    delete dd;
+    dd = nullptr;
 }
 
 bool BinEditorPlugin::initialize(const QStringList &arguments, QString *errorMessage)
@@ -523,64 +534,11 @@ bool BinEditorPlugin::initialize(const QStringList &arguments, QString *errorMes
     Q_UNUSED(arguments)
     Q_UNUSED(errorMessage)
 
-    connect(Core::EditorManager::instance(), SIGNAL(currentEditorChanged(Core::IEditor*)),
-        this, SLOT(updateCurrentEditor(Core::IEditor*)));
+    dd = new BinEditorPluginPrivate;
 
-    addAutoReleasedObject(new BinEditorFactory(this));
-    addAutoReleasedObject(new BinEditorWidgetFactory);
     return true;
 }
 
-void BinEditorPlugin::extensionsInitialized()
-{
-}
-
-void BinEditorPlugin::updateCurrentEditor(IEditor *editor)
-{
-    BinEditorWidget *binEditor = 0;
-    if (editor)
-        binEditor = qobject_cast<BinEditorWidget *>(editor->widget());
-    if (m_currentEditor == binEditor)
-        return;
-    m_currentEditor = binEditor;
-    updateActions();
-}
-
-void BinEditorPlugin::updateActions()
-{
-    bool hasEditor = (m_currentEditor != 0);
-    if (m_selectAllAction)
-        m_selectAllAction->setEnabled(hasEditor);
-    if (m_undoAction)
-        m_undoAction->setEnabled(m_currentEditor && m_currentEditor->isUndoAvailable());
-    if (m_redoAction)
-        m_redoAction->setEnabled(m_currentEditor && m_currentEditor->isRedoAvailable());
-}
-
-void BinEditorPlugin::undoAction()
-{
-    if (m_currentEditor)
-        m_currentEditor->undo();
-}
-
-void BinEditorPlugin::redoAction()
-{
-    if (m_currentEditor)
-        m_currentEditor->redo();
-}
-
-void BinEditorPlugin::copyAction()
-{
-    if (m_currentEditor)
-        m_currentEditor->copy();
-}
-
-void BinEditorPlugin::selectAllAction()
-{
-    if (m_currentEditor)
-        m_currentEditor->selectAll();
-}
-
 } // namespace Internal
 } // namespace BinEditor
 
