@@ -36,8 +36,6 @@
 #include <coreplugin/actionmanager/command.h>
 #include <coreplugin/findplaceholder.h>
 
-#include <extensionsystem/pluginmanager.h>
-
 #include <utils/hostosinfo.h>
 #include <utils/qtcassert.h>
 #include <utils/stylehelper.h>
@@ -47,6 +45,7 @@
 #include <QDebug>
 #include <QSettings>
 
+#include <QAbstractItemView>
 #include <QCheckBox>
 #include <QClipboard>
 #include <QCompleter>
@@ -118,27 +117,30 @@ FindToolBar::FindToolBar(CurrentDocumentFind *currentDocumentFind)
             this, &FindToolBar::invokeFindEnter, Qt::QueuedConnection);
     connect(m_ui.replaceEdit, &Utils::FancyLineEdit::returnPressed,
             this, &FindToolBar::invokeReplaceEnter, Qt::QueuedConnection);
+    connect(m_findCompleter,
+            static_cast<void (QCompleter::*)(const QModelIndex &)>(&QCompleter::activated),
+            this, &FindToolBar::findCompleterActivated);
 
-    QAction *shiftEnterAction = new QAction(m_ui.findEdit);
+    auto shiftEnterAction = new QAction(m_ui.findEdit);
     shiftEnterAction->setShortcut(QKeySequence(tr("Shift+Enter")));
     shiftEnterAction->setShortcutContext(Qt::WidgetShortcut);
     connect(shiftEnterAction, &QAction::triggered,
             this, &FindToolBar::invokeFindPrevious);
     m_ui.findEdit->addAction(shiftEnterAction);
-    QAction *shiftReturnAction = new QAction(m_ui.findEdit);
+    auto shiftReturnAction = new QAction(m_ui.findEdit);
     shiftReturnAction->setShortcut(QKeySequence(tr("Shift+Return")));
     shiftReturnAction->setShortcutContext(Qt::WidgetShortcut);
     connect(shiftReturnAction, &QAction::triggered,
             this, &FindToolBar::invokeFindPrevious);
     m_ui.findEdit->addAction(shiftReturnAction);
 
-    QAction *shiftEnterReplaceAction = new QAction(m_ui.replaceEdit);
+    auto shiftEnterReplaceAction = new QAction(m_ui.replaceEdit);
     shiftEnterReplaceAction->setShortcut(QKeySequence(tr("Shift+Enter")));
     shiftEnterReplaceAction->setShortcutContext(Qt::WidgetShortcut);
     connect(shiftEnterReplaceAction, &QAction::triggered,
             this, &FindToolBar::invokeReplacePrevious);
     m_ui.replaceEdit->addAction(shiftEnterReplaceAction);
-    QAction *shiftReturnReplaceAction = new QAction(m_ui.replaceEdit);
+    auto shiftReturnReplaceAction = new QAction(m_ui.replaceEdit);
     shiftReturnReplaceAction->setShortcut(QKeySequence(tr("Shift+Return")));
     shiftReturnReplaceAction->setShortcutContext(Qt::WidgetShortcut);
     connect(shiftReturnReplaceAction, &QAction::triggered,
@@ -311,8 +313,17 @@ FindToolBar::FindToolBar(CurrentDocumentFind *currentDocumentFind)
     connect(&m_findStepTimer, &QTimer::timeout, this, &FindToolBar::invokeFindStep);
 }
 
-FindToolBar::~FindToolBar()
+FindToolBar::~FindToolBar() = default;
+
+void FindToolBar::findCompleterActivated(const QModelIndex &index)
 {
+    const int findFlagsI = index.data(Find::CompletionModelFindFlagsRole).toInt();
+    const FindFlags findFlags(findFlagsI);
+    setFindFlag(FindCaseSensitively, findFlags.testFlag(FindCaseSensitively));
+    setFindFlag(FindBackward, findFlags.testFlag(FindBackward));
+    setFindFlag(FindWholeWords, findFlags.testFlag(FindWholeWords));
+    setFindFlag(FindRegularExpression, findFlags.testFlag(FindRegularExpression));
+    setFindFlag(FindPreserveCase, findFlags.testFlag(FindPreserveCase));
 }
 
 void FindToolBar::installEventFilters()
@@ -329,7 +340,7 @@ void FindToolBar::installEventFilters()
 bool FindToolBar::eventFilter(QObject *obj, QEvent *event)
 {
     if (event->type() == QEvent::KeyPress) {
-        QKeyEvent *ke = static_cast<QKeyEvent *>(event);
+        auto ke = static_cast<QKeyEvent *>(event);
         if (ke->key() == Qt::Key_Down) {
             if (obj == m_ui.findEdit) {
                 if (m_ui.findEdit->text().isEmpty())
@@ -345,7 +356,7 @@ bool FindToolBar::eventFilter(QObject *obj, QEvent *event)
 
     if ((obj == m_ui.findEdit || obj == m_findCompleter->popup())
                && event->type() == QEvent::KeyPress) {
-        QKeyEvent *ke = static_cast<QKeyEvent *>(event);
+        auto ke = static_cast<QKeyEvent *>(event);
         if (ke->key() == Qt::Key_Space && (ke->modifiers() & Utils::HostOsInfo::controlModifier())) {
             QString completedText = m_currentDocumentFind->completedFindString();
             if (!completedText.isEmpty()) {
@@ -355,7 +366,7 @@ bool FindToolBar::eventFilter(QObject *obj, QEvent *event)
             }
         }
     } else if (obj == this && event->type() == QEvent::ShortcutOverride) {
-        QKeyEvent *ke = static_cast<QKeyEvent *>(event);
+        auto ke = static_cast<QKeyEvent *>(event);
         if (ke->key() == Qt::Key_Space && (ke->modifiers() & Utils::HostOsInfo::controlModifier())) {
             event->accept();
             return true;
@@ -381,7 +392,7 @@ void FindToolBar::adaptToCandidate()
 void FindToolBar::updateGlobalActions()
 {
     IFindSupport *candidate = m_currentDocumentFind->candidate();
-    bool enabled = (candidate != 0);
+    bool enabled = (candidate != nullptr);
     bool replaceEnabled = enabled && candidate->supportsReplace();
     m_findInDocumentAction->setEnabled(enabled || (toolBarHasFocus() && isEnabled()));
     m_findNextSelectedAction->setEnabled(enabled);
@@ -529,9 +540,10 @@ void FindToolBar::invokeFindStep()
     m_findStepTimer.stop();
     m_findIncrementalTimer.stop();
     if (m_currentDocumentFind->isEnabled()) {
-        Find::updateFindCompletion(getFindText());
+        const FindFlags ef = effectiveFindFlags();
+        Find::updateFindCompletion(getFindText(), ef);
         IFindSupport::Result result =
-            m_currentDocumentFind->findStep(getFindText(), effectiveFindFlags());
+            m_currentDocumentFind->findStep(getFindText(), ef);
         indicateSearchState(result);
         if (result == IFindSupport::NotYetFound)
             m_findStepTimer.start(50);
@@ -558,9 +570,10 @@ void FindToolBar::invokeReplace()
 {
     setFindFlag(FindBackward, false);
     if (m_currentDocumentFind->isEnabled() && m_currentDocumentFind->supportsReplace()) {
-        Find::updateFindCompletion(getFindText());
+        const FindFlags ef = effectiveFindFlags();
+        Find::updateFindCompletion(getFindText(), ef);
         Find::updateReplaceCompletion(getReplaceText());
-        m_currentDocumentFind->replace(getFindText(), getReplaceText(), effectiveFindFlags());
+        m_currentDocumentFind->replace(getFindText(), getReplaceText(), ef);
     }
 }
 
@@ -597,18 +610,20 @@ void FindToolBar::invokeGlobalReplacePrevious()
 void FindToolBar::invokeReplaceStep()
 {
     if (m_currentDocumentFind->isEnabled() && m_currentDocumentFind->supportsReplace()) {
-        Find::updateFindCompletion(getFindText());
+        const FindFlags ef = effectiveFindFlags();
+        Find::updateFindCompletion(getFindText(), ef);
         Find::updateReplaceCompletion(getReplaceText());
-        m_currentDocumentFind->replaceStep(getFindText(), getReplaceText(), effectiveFindFlags());
+        m_currentDocumentFind->replaceStep(getFindText(), getReplaceText(), ef);
     }
 }
 
 void FindToolBar::invokeReplaceAll()
 {
-    Find::updateFindCompletion(getFindText());
+    const FindFlags ef = effectiveFindFlags();
+    Find::updateFindCompletion(getFindText(), ef);
     Find::updateReplaceCompletion(getReplaceText());
     if (m_currentDocumentFind->isEnabled() && m_currentDocumentFind->supportsReplace())
-        m_currentDocumentFind->replaceAll(getFindText(), getReplaceText(), effectiveFindFlags());
+        m_currentDocumentFind->replaceAll(getFindText(), getReplaceText(), ef);
 }
 
 void FindToolBar::invokeGlobalReplaceAll()
@@ -637,9 +652,8 @@ void FindToolBar::putSelectionToFindClipboard()
 void FindToolBar::updateFromFindClipboard()
 {
     if (QApplication::clipboard()->supportsFindBuffer()) {
-        const bool blocks = m_ui.findEdit->blockSignals(true);
+        QSignalBlocker blocker(m_ui.findEdit);
         setFindText(QApplication::clipboard()->text(QClipboard::FindBuffer));
-        m_ui.findEdit->blockSignals(blocks);
     }
 }
 
@@ -654,7 +668,7 @@ void FindToolBar::findFlagsChanged()
 
 void FindToolBar::findEditButtonClicked()
 {
-    OptionsPopup *popup = new OptionsPopup(m_ui.findEdit);
+    auto popup = new OptionsPopup(m_ui.findEdit);
     popup->show();
 }
 
@@ -666,11 +680,11 @@ void FindToolBar::updateIcons()
     bool regexp = effectiveFlags & FindRegularExpression;
     bool preserveCase = effectiveFlags & FindPreserveCase;
     if (!casesensitive && !wholewords && !regexp && !preserveCase) {
-        const QPixmap pixmap = Icons::MAGNIFIER.pixmap();
-        m_ui.findEdit->setButtonPixmap(Utils::FancyLineEdit::Left, pixmap);
+        const QIcon icon = Utils::Icons::MAGNIFIER.icon();
+        m_ui.findEdit->setButtonIcon(Utils::FancyLineEdit::Left, icon);
     } else {
-        m_ui.findEdit->setButtonPixmap(Utils::FancyLineEdit::Left,
-                                       IFindFilter::pixmapForFindFlags(effectiveFlags));
+        m_ui.findEdit->setButtonIcon(Utils::FancyLineEdit::Left,
+                                     IFindFilter::pixmapForFindFlags(effectiveFlags));
     }
 }
 
@@ -728,21 +742,21 @@ void FindToolBar::hideAndResetFocus()
 
 FindToolBarPlaceHolder *FindToolBar::findToolBarPlaceHolder() const
 {
-    QList<FindToolBarPlaceHolder*> placeholders = ExtensionSystem::PluginManager::getObjects<FindToolBarPlaceHolder>();
+    const QList<FindToolBarPlaceHolder*> placeholders = FindToolBarPlaceHolder::allFindToolbarPlaceHolders();
     QWidget *candidate = QApplication::focusWidget();
     while (candidate) {
-        foreach (FindToolBarPlaceHolder *ph, placeholders) {
+        for (FindToolBarPlaceHolder *ph : placeholders) {
             if (ph->owner() == candidate)
                 return ph;
         }
         candidate = candidate->parentWidget();
     }
-    return 0;
+    return nullptr;
 }
 
 bool FindToolBar::toolBarHasFocus() const
 {
-    return qApp->focusWidget() == focusWidget();
+    return QApplication::focusWidget() == focusWidget();
 }
 
 bool FindToolBar::canShowAllControls(bool replaceIsVisible) const
@@ -810,7 +824,7 @@ void FindToolBar::openFindToolBar(OpenFlags flags)
     FindToolBarPlaceHolder *previousHolder = FindToolBarPlaceHolder::getCurrent();
     if (previousHolder != holder) {
         if (previousHolder)
-            previousHolder->setWidget(0);
+            previousHolder->setWidget(nullptr);
         holder->setWidget(this);
         FindToolBarPlaceHolder::setCurrent(holder);
     }
@@ -957,17 +971,13 @@ void FindToolBar::setBackward(bool backward)
 void FindToolBar::setLightColoredIcon(bool lightColored)
 {
     if (lightColored) {
-        m_ui.findNextButton->setIcon(QIcon());
-        m_ui.findNextButton->setArrowType(Qt::RightArrow);
-        m_ui.findPreviousButton->setIcon(QIcon());
-        m_ui.findPreviousButton->setArrowType(Qt::LeftArrow);
-        m_ui.close->setIcon(Icons::CLOSE_FOREGROUND.icon());
+        m_ui.findNextButton->setIcon(Utils::Icons::NEXT.icon());
+        m_ui.findPreviousButton->setIcon(Utils::Icons::PREV.icon());
+        m_ui.close->setIcon(Utils::Icons::CLOSE_FOREGROUND.icon());
     } else {
         m_ui.findNextButton->setIcon(Utils::Icons::NEXT_TOOLBAR.icon());
-        m_ui.findNextButton->setArrowType(Qt::NoArrow);
         m_ui.findPreviousButton->setIcon(Utils::Icons::PREV_TOOLBAR.icon());
-        m_ui.findPreviousButton->setArrowType(Qt::NoArrow);
-        m_ui.close->setIcon(Icons::CLOSE_TOOLBAR.icon());
+        m_ui.close->setIcon(Utils::Icons::CLOSE_TOOLBAR.icon());
     }
 }
 
@@ -975,7 +985,7 @@ OptionsPopup::OptionsPopup(QWidget *parent)
     : QWidget(parent, Qt::Popup)
 {
     setAttribute(Qt::WA_DeleteOnClose);
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
     layout->setContentsMargins(2, 2, 2, 2);
     layout->setSpacing(2);
     setLayout(layout);
@@ -991,7 +1001,7 @@ OptionsPopup::OptionsPopup(QWidget *parent)
 bool OptionsPopup::event(QEvent *ev)
 {
     if (ev->type() == QEvent::ShortcutOverride) {
-        QKeyEvent *ke = static_cast<QKeyEvent *>(ev);
+        auto ke = static_cast<QKeyEvent *>(ev);
         if (ke->key() == Qt::Key_Escape && !ke->modifiers()) {
             ev->accept();
             return true;
@@ -1002,9 +1012,9 @@ bool OptionsPopup::event(QEvent *ev)
 
 bool OptionsPopup::eventFilter(QObject *obj, QEvent *ev)
 {
-    QCheckBox *checkbox = qobject_cast<QCheckBox *>(obj);
+    auto checkbox = qobject_cast<QCheckBox *>(obj);
     if (ev->type() == QEvent::KeyPress && checkbox) {
-        QKeyEvent *ke = static_cast<QKeyEvent *>(ev);
+        auto ke = static_cast<QKeyEvent *>(ev);
         if (!ke->modifiers() && (ke->key() == Qt::Key_Enter || ke->key() == Qt::Key_Return)) {
             checkbox->click();
             ev->accept();
@@ -1016,7 +1026,7 @@ bool OptionsPopup::eventFilter(QObject *obj, QEvent *ev)
 
 void OptionsPopup::actionChanged()
 {
-    QAction *action = qobject_cast<QAction *>(sender());
+    auto action = qobject_cast<QAction *>(sender());
     QTC_ASSERT(action, return);
     QCheckBox *checkbox = m_checkboxMap.value(action);
     QTC_ASSERT(checkbox, return);
