@@ -114,13 +114,13 @@ public:
         m_fixupExpando = expando;
     }
 
-    QValidator::State validate(QString &input, int &pos) const
+    QValidator::State validate(QString &input, int &pos) const override
     {
         fixup(input);
         return QRegularExpressionValidator::validate(input, pos);
     }
 
-    void fixup(QString &fixup) const
+    void fixup(QString &fixup) const override
     {
         if (m_fixupExpando.isEmpty())
             return;
@@ -139,14 +139,13 @@ private:
 // JsonFieldPage::FieldData:
 // --------------------------------------------------------------------
 
-JsonFieldPage::Field::Field() : d(new FieldPrivate)
+JsonFieldPage::Field::Field() : d(std::make_unique<FieldPrivate>())
 { }
 
 JsonFieldPage::Field::~Field()
 {
     delete d->m_widget;
     delete d->m_label;
-    delete d;
 }
 
 QString JsonFieldPage::Field::type()
@@ -159,7 +158,7 @@ JsonFieldPage::Field *JsonFieldPage::Field::parse(const QVariant &input, QString
     if (input.type() != QVariant::Map) {
         *errorMessage = QCoreApplication::translate("ProjectExplorer::JsonFieldPage",
                                                     "Field is not an object.");
-        return 0;
+        return nullptr;
     }
 
     QVariantMap tmp = input.toMap();
@@ -167,13 +166,13 @@ JsonFieldPage::Field *JsonFieldPage::Field::parse(const QVariant &input, QString
     if (name.isEmpty()) {
         *errorMessage = QCoreApplication::translate("ProjectExplorer::JsonFieldPage",
                                                     "Field has no name.");
-        return 0;
+        return nullptr;
     }
     const QString type = consumeValue(tmp, TYPE_KEY).toString();
     if (type.isEmpty()) {
         *errorMessage = QCoreApplication::translate("ProjectExplorer::JsonFieldPage",
                                                     "Field \"%1\" has no type.").arg(name);
-        return 0;
+        return nullptr;
     }
 
     Field *data = createFieldData(type);
@@ -181,7 +180,7 @@ JsonFieldPage::Field *JsonFieldPage::Field::parse(const QVariant &input, QString
         *errorMessage = QCoreApplication::translate("ProjectExplorer::JsonFieldPage",
                                                     "Field \"%1\" has unsupported type \"%2\".")
                 .arg(name).arg(type);
-        return 0;
+        return nullptr;
     }
     data->setTexts(name,
                    JsonWizardFactory::localizedString(consumeValue(tmp, DISPLAY_NAME_KEY).toString()),
@@ -200,7 +199,7 @@ JsonFieldPage::Field *JsonFieldPage::Field::parse(const QVariant &input, QString
                                                     "When parsing Field \"%1\": %2")
                 .arg(name).arg(*errorMessage);
         delete data;
-        return 0;
+        return nullptr;
     }
 
     warnAboutUnsupportedKeys(tmp, name);
@@ -879,7 +878,6 @@ bool ListField::parseData(const QVariant &data, QString *errorMessage)
 
     for (const QVariant &i : value.toList()) {
         std::unique_ptr<QStandardItem> item = createStandardItemFromListItem(i, errorMessage);
-        QString test = item->text();
         QTC_ASSERT(!item || !item->text().isEmpty(), continue);
         m_itemList.emplace_back(std::move(item));
     }
@@ -927,7 +925,7 @@ void ListField::initializeData(MacroExpander *expander)
 
         QString iconPath = expandedValuesItem->data(IconStringRole).toString();
         if (!iconPath.isEmpty()) {
-            if (JsonFieldPage *page = qobject_cast<JsonFieldPage*>(widget()->parentWidget())) {
+            if (auto *page = qobject_cast<JsonFieldPage*>(widget()->parentWidget())) {
                 const QString wizardDirectory = page->value("WizardDir").toString();
                 iconPath = QDir::cleanPath(QDir(wizardDirectory).absoluteFilePath(iconPath));
                 if (QFileInfo::exists(iconPath)) {
