@@ -32,26 +32,29 @@
 #include "qmakeprojectmanagerconstants.h"
 #include "qmakenodes.h"
 #include "qmakestep.h"
-#include "makestep.h"
+#include "qmakemakestep.h"
 #include "makefileparse.h"
 
 #include <coreplugin/documentmanager.h>
 #include <coreplugin/icore.h>
 
+#include <projectexplorer/buildmanager.h>
 #include <projectexplorer/buildsteplist.h>
 #include <projectexplorer/kit.h>
+#include <projectexplorer/projectexplorer.h>
 #include <projectexplorer/projectexplorerconstants.h>
 #include <projectexplorer/projectmacroexpander.h>
 #include <projectexplorer/target.h>
 #include <projectexplorer/toolchain.h>
 #include <projectexplorer/toolchainmanager.h>
+
 #include <qtsupport/qtkitinformation.h>
 #include <qtsupport/qtversionmanager.h>
+
 #include <utils/mimetypes/mimedatabase.h>
 #include <utils/qtcassert.h>
 #include <utils/qtcprocess.h>
 #include <utils/qtcassert.h>
-#include <android/androidmanager.h>
 
 #include <QDebug>
 #include <QInputDialog>
@@ -98,8 +101,8 @@ const char BUILD_CONFIGURATION_KEY[] = "Qt4ProjectManager.Qt4BuildConfiguration.
 
 enum { debug = 0 };
 
-QmakeBuildConfiguration::QmakeBuildConfiguration(Target *target)
-    : BuildConfiguration(target, Constants::QMAKE_BC_ID)
+QmakeBuildConfiguration::QmakeBuildConfiguration(Target *target, Core::Id id)
+    : BuildConfiguration(target, id)
 {
     connect(this, &BuildConfiguration::buildDirectoryChanged,
             this, &QmakeBuildConfiguration::emitProFileEvaluateNeeded);
@@ -127,12 +130,12 @@ void QmakeBuildConfiguration::initialize(const BuildInfo *info)
     BuildStepList *buildSteps = stepList(ProjectExplorer::Constants::BUILDSTEPS_BUILD);
     auto qmakeStep = new QMakeStep(buildSteps);
     buildSteps->appendStep(qmakeStep);
-    buildSteps->appendStep(new MakeStep(buildSteps));
+    buildSteps->appendStep(new QmakeMakeStep(buildSteps));
 
     BuildStepList *cleanSteps = stepList(ProjectExplorer::Constants::BUILDSTEPS_CLEAN);
-    cleanSteps->appendStep(new MakeStep(cleanSteps));
+    cleanSteps->appendStep(new QmakeMakeStep(cleanSteps));
 
-    const QmakeBuildInfo *qmakeInfo = static_cast<const QmakeBuildInfo *>(info);
+    const auto *qmakeInfo = static_cast<const QmakeBuildInfo *>(info);
     BaseQtVersion *version = QtKitInformation::qtVersion(target()->kit());
 
     BaseQtVersion::QmakeBuildConfigs config = version->defaultBuildConfig();
@@ -160,9 +163,7 @@ void QmakeBuildConfiguration::initialize(const BuildInfo *info)
     updateCacheAndEmitEnvironmentChanged();
 }
 
-QmakeBuildConfiguration::~QmakeBuildConfiguration()
-{
-}
+QmakeBuildConfiguration::~QmakeBuildConfiguration() = default;
 
 QVariantMap QmakeBuildConfiguration::toMap() const
 {
@@ -306,24 +307,24 @@ QStringList QmakeBuildConfiguration::configCommandLineArguments() const
 
 QMakeStep *QmakeBuildConfiguration::qmakeStep() const
 {
-    QMakeStep *qs = 0;
+    QMakeStep *qs = nullptr;
     BuildStepList *bsl = stepList(Core::Id(ProjectExplorer::Constants::BUILDSTEPS_BUILD));
     Q_ASSERT(bsl);
     for (int i = 0; i < bsl->count(); ++i)
-        if ((qs = qobject_cast<QMakeStep *>(bsl->at(i))) != 0)
+        if ((qs = qobject_cast<QMakeStep *>(bsl->at(i))) != nullptr)
             return qs;
-    return 0;
+    return nullptr;
 }
 
-MakeStep *QmakeBuildConfiguration::makeStep() const
+QmakeMakeStep *QmakeBuildConfiguration::makeStep() const
 {
-    MakeStep *ms = 0;
+    QmakeMakeStep *ms = nullptr;
     BuildStepList *bsl = stepList(Core::Id(ProjectExplorer::Constants::BUILDSTEPS_BUILD));
     Q_ASSERT(bsl);
     for (int i = 0; i < bsl->count(); ++i)
-        if ((ms = qobject_cast<MakeStep *>(bsl->at(i))) != 0)
+        if ((ms = qobject_cast<QmakeMakeStep *>(bsl->at(i))) != nullptr)
             return ms;
-    return 0;
+    return nullptr;
 }
 
 // Returns true if both are equal.
@@ -357,9 +358,11 @@ QmakeBuildConfiguration::MakefileState QmakeBuildConfiguration::compareToImportF
         return MakefileForWrongProject;
     }
 
-    if (parse.srcProFile() != qs->project()->projectFilePath().toString()) {
+    const Utils::FileName projectPath =
+            m_subNodeBuild ? m_subNodeBuild->filePath() : qs->project()->projectFilePath();
+    if (parse.srcProFile() != projectPath.toString()) {
         qCDebug(logs) << "**Different profile used to generate the Makefile:"
-                      << parse.srcProFile() << " expected profile:" << qs->project()->projectFilePath();
+                      << parse.srcProFile() << " expected profile:" << projectPath;
         if (errorString)
             *errorString = tr("The Makefile is for a different project.");
         return MakefileIncompatible;
@@ -387,7 +390,7 @@ QmakeBuildConfiguration::MakefileState QmakeBuildConfiguration::compareToImportF
     // and compare that on its own
     QString workingDirectory = QFileInfo(makefile).absolutePath();
     QStringList actualArgs;
-    QString userArgs = qs->userArguments();
+    QString userArgs = macroExpander()->expandProcessArgs(qs->userArguments());
     // This copies the settings from userArgs to actualArgs (minus some we
     // are not interested in), splitting them up into individual strings:
     extractSpecFromArguments(&userArgs, workingDirectory, version, &actualArgs);
@@ -558,7 +561,7 @@ QmakeBuildInfo *QmakeBuildConfigurationFactory::createBuildInfo(const Kit *k,
                                                               BuildConfiguration::BuildType type) const
 {
     BaseQtVersion *version = QtKitInformation::qtVersion(k);
-    QmakeBuildInfo *info = new QmakeBuildInfo(this);
+    auto *info = new QmakeBuildInfo(this);
     QString suffix;
     if (type == BuildConfiguration::Release) {
         //: The name of the release build configuration created by default for a qmake project.
@@ -670,7 +673,7 @@ void QmakeBuildConfiguration::setupBuildEnvironment(Kit *k, Environment &env)
         env.prependOrSetPath(qt->binPath().toString());
 }
 
-QmakeBuildConfiguration::LastKitState::LastKitState() { }
+QmakeBuildConfiguration::LastKitState::LastKitState() = default;
 
 QmakeBuildConfiguration::LastKitState::LastKitState(Kit *k)
     : m_qtVersion(QtKitInformation::qtVersionId(k)),
@@ -694,4 +697,24 @@ bool QmakeBuildConfiguration::LastKitState::operator !=(const LastKitState &othe
     return !operator ==(other);
 }
 
+bool QmakeBuildConfiguration::regenerateBuildFiles(Node *node)
+{
+    QMakeStep *qs = qmakeStep();
+    if (!qs)
+        return false;
+
+    qs->setForced(true);
+
+    BuildManager::buildList(stepList(ProjectExplorer::Constants::BUILDSTEPS_CLEAN));
+    BuildManager::appendStep(qs, ProjectExplorerPlugin::displayNameForStepId(ProjectExplorer::Constants::BUILDSTEPS_CLEAN));
+
+    QmakeProFileNode *proFile = nullptr;
+    if (node && node != target()->project()->rootProjectNode())
+        proFile = dynamic_cast<QmakeProFileNode *>(node);
+
+    setSubNodeBuild(proFile);
+
+    return true;
+}
+
 } // namespace QmakeProjectManager
