@@ -71,7 +71,7 @@ QColor convertColorFromString(const QString &s)
         uchar r = fromHex(s, 3);
         uchar g = fromHex(s, 5);
         uchar b = fromHex(s, 7);
-        return QColor(r, g, b, a);
+        return {r, g, b, a};
     } else {
         QColor rv(s);
         return rv;
@@ -84,9 +84,9 @@ PropertyEditorContextObject::PropertyEditorContextObject(QObject *parent) :
     QObject(parent),
     m_isBaseState(false),
     m_selectionChanged(false),
-    m_backendValues(0),
-    m_qmlComponent(0),
-    m_qmlContext(0)
+    m_backendValues(nullptr),
+    m_qmlComponent(nullptr),
+    m_qmlContext(nullptr)
 {
 
 }
@@ -342,7 +342,7 @@ void PropertyEditorContextObject::setSpecificQmlData(const QString &newSpecificQ
     m_specificQmlData = newSpecificQmlData;
 
     delete m_qmlComponent;
-    m_qmlComponent = 0;
+    m_qmlComponent = nullptr;
 
     emit specificQmlComponentChanged();
     emit specificQmlDataChanged();
