@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt Creator.
 **
@@ -9,22 +9,17 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://www.qt.io/licensing.  For further information
-** use the contact form at http://www.qt.io/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ****************************************************************************/
 
@@ -63,13 +58,13 @@ void Indenter::indentBlock(QTextDocument *doc,
 {
     Q_UNUSED(doc)
 
-    QmlJSTools::CreatorCodeFormatter codeFormatter(tabSettings);
-
-    codeFormatter.updateStateUntil(block);
-    const int depth = codeFormatter.indentFor(block);
+    const int depth = indentFor(block, tabSettings);
     if (depth == -1)
         return;
 
+    QmlJSTools::CreatorCodeFormatter codeFormatter(tabSettings);
+    codeFormatter.updateStateUntil(block);
+
     if (isElectricCharacter(typedChar)) {
         // only reindent the current line when typing electric characters if the
         // indent is the same it would be if the line were empty
@@ -86,3 +81,28 @@ void Indenter::invalidateCache(QTextDocument *doc)
     QmlJSTools::CreatorCodeFormatter codeFormatter;
     codeFormatter.invalidateCache(doc);
 }
+
+
+int Indenter::indentFor(const QTextBlock &block,
+                        const TextEditor::TabSettings &tabSettings)
+{
+    QmlJSTools::CreatorCodeFormatter codeFormatter(tabSettings);
+    codeFormatter.updateStateUntil(block);
+    return codeFormatter.indentFor(block);
+}
+
+
+TextEditor::IndentationForBlock
+Indenter::indentationForBlocks(const QVector<QTextBlock> &blocks,
+                               const TextEditor::TabSettings &tabSettings)
+{
+    QmlJSTools::CreatorCodeFormatter codeFormatter(tabSettings);
+
+
+    codeFormatter.updateStateUntil(blocks.last());
+
+    TextEditor::IndentationForBlock ret;
+    foreach (QTextBlock block, blocks)
+        ret.insert(block.blockNumber(), codeFormatter.indentFor(block));
+    return ret;
+}
